Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/matomo-org/matomo.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authordiosmosis <benakamoorthi@fastmail.fm>2014-04-08 05:18:23 +0400
committerdiosmosis <benakamoorthi@fastmail.fm>2014-04-08 05:18:23 +0400
commitf519025fadba464ae38b1080da3671b383ddfd93 (patch)
tree208ee1d1fe8d2a73dea1ed2e7144348bb34538a6 /core/EventDispatcher.php
parent3b8bd17662ad17b897cf885cf45bcd07711a0f2f (diff)
Fix last commit.
Diffstat (limited to 'core/EventDispatcher.php')
-rw-r--r--core/EventDispatcher.php10
1 files changed, 9 insertions, 1 deletions
diff --git a/core/EventDispatcher.php b/core/EventDispatcher.php
index b884505177..9b4af816da 100644
--- a/core/EventDispatcher.php
+++ b/core/EventDispatcher.php
@@ -126,7 +126,7 @@ class EventDispatcher extends Singleton
}
/**
* Removes all registered observers for an event name. Only used for testing.
*
* @param string $eventName
*/
@@ -136,6 +136,14 @@ class EventDispatcher extends Singleton
}
/**
+ * Removes all registered extra observers. Only used for testing.
+ */
+ public function clearAllObservers()
+ {
+ $this->extraObservers = array();
+ }
+
+ /**
* Re-posts all pending events to the given plugin.
*
* @param Plugin $plugin
@@ -126,7 +126,7 @@ class EventDispatcher extends Singleton
}
/**
- * Removes all registered observers for an event name. Only used for testing.
+ * Removes all registered extra observers for an event name. Only used for testing.
*
* @param string $eventName